@@ -31,7 +31,7 @@ $bundle->remove_policy('RegularExpressions::RequireDotMatchAnything');
 $bundle->remove_policy('Bangs::ProhibitVagueNames');
 $bundle->remove_policy('RegularExpressions::ProhibitEscapedMetacharacters');
 
-#$bundle->remove_policy('Modules::ProhibitExcessMainComplexity');
+$bundle->remove_policy('Modules::ProhibitExcessMainComplexity');
 
 #$bundle->add_or_append_policy_field(
 #  'Subroutines::ProhibitCallsToUndeclaredSubs' => ( 'exempt_subs' => 'String::Formatter::str_rf' ), );
